spindry.VaryingEpsilonPotential
===============================

.. currentmodule:: spindry

.. autoclass:: VaryingEpsilonPotential
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~VaryingEpsilonPotential.compute_potential
   
   

   
   
   